@@ -1,8 +1,7 @@
-SEXP C_MIM(SEXP X,SEXP Y,SEXP K){
- int nt=omp_get_max_threads();
- int n,k,m,ny,*y,*nx,**x;
- struct ht *hta[nt];
- prepareInput(X,Y,K,hta,&n,&m,&k,&y,&ny,&x,&nx,nt);
+SEXP C_MIM(SEXP X,SEXP Y,SEXP K,SEXP Threads){
+ int n,k,m,ny,*y,*nx,**x,nt;
+ struct ht **hta;
+ prepareInput(X,Y,K,Threads,&hta,&n,&m,&k,&y,&ny,&x,&nx,&nt);
  int *cXc=(int*)R_alloc(sizeof(int),n*nt);
  int *cYc=(int*)R_alloc(sizeof(int),n*nt);
  double *mi=(double*)R_alloc(sizeof(double),m);
@@ -12,10 +11,10 @@ SEXP C_MIM(SEXP X,SEXP Y,SEXP K){
  SEXP Ans; PROTECT(Ans=makeAns(k,&score,&idx));
 
  for(int e=0;e<k;e++){
-  score[e]=0; idx[e]=-1;
+  score[e]=0.; idx[e]=-1;
  }
 
- #pragma omp parallel
+ #pragma omp parallel num_threads(nt)
  { 
   int tn=omp_get_thread_num(),*cX=cXc+(tn*n),*cY=cYc+(tn*n),dy=0;
   struct ht *ht=hta[tn];
@@ -27,7 +26,7 @@ SEXP C_MIM(SEXP X,SEXP Y,SEXP K){
  }
 
  //Insertion sort since we need stable sort in principle
- for(int e=0;e<m;e++) if(score[k-1]<=mi[e]){
+ for(int e=0;e<m;e++) if(score[k-1]<mi[e]){
   int ee;
   for(ee=k-2;ee>=0 && score[ee]<mi[e];ee--){
    score[ee+1]=score[ee]; idx[ee+1]=idx[ee];
