@@ -1,10 +1,3 @@
-#include <R.h>
-#include <Rdefines.h>
-#include <Rinternals.h>
-#include <R_ext/Utils.h>
-#include <R_ext/Rdynload.h>
-#include <R_ext/Visibility.h> 
-
 #ifdef _OPENMP
  #include <omp.h>
 #else
@@ -13,6 +6,13 @@
  #define omp_set_num_threads(x)
 #endif
 
+#include <R.h>
+#include <Rdefines.h>
+#include <Rinternals.h>
+#include <R_ext/Utils.h>
+#include <R_ext/Rdynload.h>
+#include <R_ext/Visibility.h> 
+
 //Hash table
 
 #include "ht.h"
@@ -41,6 +41,7 @@
 #include "mis.h"
 #include "cmis.h"
 #include "jmis.h"
+#include "maxjmis.h"
 #include "ims.h"
 #include "hs.h"
 #include "trips.h"
@@ -72,8 +73,11 @@ static const R_CallMethodDef R_CallDef[]={
  CALLDEF(C_miMatrix,3),
  CALLDEF(C_jmi,4),
  CALLDEF(C_njmi,4),
+ CALLDEF(C_max_jmi,3),
+ CALLDEF(C_max_cmi,3),
  CALLDEF(C_cmi,4),
  CALLDEF(C_cmiMatrix,4),
+ CALLDEF(C_cmiMatrix2,3),
  CALLDEF(C_jmiMatrix,4),
  CALLDEF(C_njmiMatrix,4),
  CALLDEF(C_nmiMatrix,3),
