@@ -71,13 +71,14 @@ c(
  "CMI","MIM","JMIM","NJMIM","JMI","DISR","CMIM","MRMR",
  "cmiMatrix","cmiScores","dnmiMatrix","hScores","impScores",
  "jmiMatrix","jmiScores","miMatrix","miScores","njmiMatrix",
- "njmiScores","nmiMatrix"
+ "njmiScores","nmiMatrix","maxJmiScores","maxCmiScores",
+ "minCmiScores"
 )->algos
 for(algo in algos){
  test_that(sprintf("Named vector X work with %s",algo),{
   if(grepl("^h",algo)){
    z<-do.call(algo,list(c(a=1,b=2,c=3)))
-  }else if(grepl("(^mi|^imp|^dnmi|^nmi)",algo)){
+  }else if(grepl("(^mi|^imp|^dnmi|^nmi|^maxJmi|^maxCmi|^minCmi)",algo)){
    z<-do.call(algo,list(c(a=1,b=2,c=3),1:3))
   }else if(grepl("(^cmi|^jmi|^njmi)",algo)){
    z<-do.call(algo,list(c(a=1,b=2,c=3),1:3,3:1))
